Tools for reporting and forecasting viral respiratory infections, using case surveillance data. Report generation tools for short-term forecasts, and validation metrics for an arbitrary number of customizable respiratory viruses. Estimation of the effective reproduction number is based on the 'EpiEstim' framework described in work by 'Cori' and colleagues. (2013) tools:::Rd_expr_doi("10.1093/aje/kwt133").
Maintainer: Mike Irvine mike.irvine@bccdc.ca [copyright holder]
Authors:
Caesar Wong
Nirupama Tamvada
Rebeca Falcao
Nelson Tang
Useful links: