Learn R Programming

ViroReportR (version 1.0.4)

current_forecast_text: Print out text output for ViroReportR report detailing current number of case visits, last value of Rt and corresponding intervals

Description

Print out text output for ViroReportR report detailing current number of case visits, last value of Rt and corresponding intervals

Usage

current_forecast_text(time_period_result, ...)

Value

current forecast metrics

Arguments

time_period_result

output from forecast_time_period

...

optional arguments to be passed on to forecast_metrics